--[[
SHORT DESCRIPTION OF WHAT YOUR MOD DOES GOES HERE

Author:     w33zl
Version:    1.0.0
Modified:   2025-02-12

Changelog:

]]


NoExoticCrops = Mod:init()

NoExoticCrops.DISABLED_CROPS = {
    "olive",
    "grape",
    "cotton",
    "sugarcane",
    "rice",
    "riceLongGrain"
}

NoExoticCrops.XML_KEY = "disabledCrops"

function NoExoticCrops:loadMap(filename)
end

function NoExoticCrops:loadSavegame(xmlFile, key)
    -- Log:debug("NoExoticCrops:loadFromXMLFile")

    self.LOADED_CHECKSUM = xmlFile:getString(key .. "#" .. self.XML_KEY, "")

    -- Log:var("disabledCrops", self.LOADED_CHECKSUM)

    self.checksumOk = self.LOADED_CHECKSUM == "" or self.CHECKSUM == self.LOADED_CHECKSUM
end

function NoExoticCrops:saveSavegame(xmlFile, key)
    -- Log:debug("FarmExtension:saveToXMLFile")

    xmlFile:setString(key .. "#" .. self.XML_KEY, self.CHECKSUM)

end

function NoExoticCrops:disableCrops()
    self.CHECKSUM = ""
    for _, cropName in ipairs(NoExoticCrops.DISABLED_CROPS) do
        g_fruitTypeManager:getFruitTypeByName(cropName).shownOnMap = false
        self.CHECKSUM = self.CHECKSUM .. cropName .. "|"
    end
end

function NoExoticCrops:startMission()
    local isAnyEnabled = false
    for _, cropName in ipairs(NoExoticCrops.DISABLED_CROPS) do
        if g_fruitTypeManager:getFruitTypeByName(cropName).shownOnMap then
            isAnyEnabled = true
            break
        end
    end

    if isAnyEnabled then
        Log:warning("Failed to disable one or more crops.")
    else
        Log:info("All exotic crops successfully disabled.")
    end

    -- Log:var("self.checksumOk", self.checksumOk)
    -- Log:var("self.CHECKSUM", self.CHECKSUM)
    -- Log:var("self.LOADED_CHECKSUM", self.LOADED_CHECKSUM)

    if self.LOADED_CHECKSUM ~= nil and not self.checksumOk then
        Log:warning("Checksum mismatch, something is wrong. Expected '%s', got '%s'", self.CHECKSUM, self.LOADED_CHECKSUM)
    end
end

function NoExoticCrops:update()
    if self.dialogShown or g_gui:getIsGuiVisible() then
        return
    end
    self.dialogShown = true

    if self.LOADED_CHECKSUM == nil then
        InfoDialog.show(g_i18n:getText("ui_newGameStarted"), nil, nil, DialogElement.TYPE_INFO)
    elseif self.LOADED_CHECKSUM == "" then
        InfoDialog.show(g_i18n:getText("ui_addedToSavegame"), nil, nil, DialogElement.TYPE_WARNING)
    elseif not self.checksumOk then
        InfoDialog.show(g_i18n:getText("ui_disabledCropsMismatch"), nil, nil, DialogElement.TYPE_WARNING)
    end
end

FruitTypeManager.loadMapData = Utils.overwrittenFunction(FruitTypeManager.loadMapData, function (self, superFunc, xmlFileHandle, missionInfo, baseDirectory)
    Log:debug("FruitTypeManager.loadMapData")
    local retVal = superFunc(self, xmlFileHandle, missionInfo, baseDirectory)
    NoExoticCrops:disableCrops()
    return retVal
end)

Farm.saveToXMLFile = Utils.appendedFunction(Farm.saveToXMLFile, function(self, xmlFile, key)
    NoExoticCrops:saveSavegame(xmlFile, key)
end)

Farm.loadFromXMLFile = Utils.appendedFunction(Farm.loadFromXMLFile, function(self, xmlFile, key)
    NoExoticCrops:loadSavegame(xmlFile, key)
end)